@@ -1,18 +1,20 @@
 from abc import ABC, abstractmethod
 from typing import Optional, Tuple
 
+from sweelimiter.api.interval import Interval
+
 
 class Backend(ABC):
 
     @abstractmethod
-    async def process(self, key: str, interval_ms: int, limit: int) -> Tuple[Optional[str], dict]:
+    async def process(self, key: str, interval: Interval, limit: int) -> Tuple[Optional[str], dict]:
         pass
 
 
 class CountingBackend(Backend):
 
-    async def process(self, key: str, interval_ms: int, limit: int) -> Tuple[Optional[str], dict]:
-        requests_made = self.get_and_increment(key, interval_ms, limit)
+    async def process(self, key: str, interval: Interval, limit: int) -> Tuple[Optional[str], dict]:
+        requests_made = self.get_and_increment(key, interval, limit)
         meta = {
             'key': key,
             'requests_made': requests_made,
@@ -22,10 +24,10 @@ class CountingBackend(Backend):
 
         result = None
         if requests_made > limit:
-            result = f'Hit limiter {key}: {limit} allowed per {interval_ms}ms'
+            result = f'Hit limiter {key}: {limit} allowed per {interval}'
 
         return result, meta
 
     @abstractmethod
-    def get_and_increment(self, key: str, interval_ms: int, limit: int) -> int:
+    def get_and_increment(self, key: str, interval: Interval, limit: int) -> int:
         pass
