@@ -12,8 +12,6 @@ class KeyExtractor:
 
     def extract(self, req: Request) -> List[str]:
         keys = self.fn(req)
-        return [f'{self.prefix}@{key}' for key in keys]
+        return [f'{self.prefix}{key}' for key in keys]
 
 
-def new_extractor(prefix: str, fn: KeyExtractorFn):
-    return KeyExtractor(prefix, fn)
\ No newline at end of file
