@@ -3,6 +3,7 @@ import time
 from typing import Optional, Tuple, Callable
 
 from sweelimiter.api.backend import Backend
+from sweelimiter.api.interval import Interval
 
 try:
     from asyncio_redis import Connection
@@ -12,19 +13,19 @@ except ImportError:
 
 class AsyncioRedisBackend(Backend):
 
-    async def process(self, key: str, interval_ms: int, limit: int) -> Tuple[Optional[str], dict]:
+    async def process(self, key: str, interval: Interval, limit: int) -> Tuple[Optional[str], dict]:
         redis_key = 'limiter_' + key
         r = self._redis()
 
         time_now = int(time.time_ns() // 1_000_000)
 
-        separation = round(interval_ms / limit)
+        separation = round(interval.to_miliseconds() / limit)
 
         await r.setnx(redis_key, '0')
         tat = max(int(await r.get(redis_key)), time_now)
 
         wait_left = tat - time_now
-        est_interval = interval_ms - separation
+        est_interval = interval.to_miliseconds() - separation
 
         if wait_left <= est_interval:
             new_tat = max(tat, time_now) + separation
@@ -37,7 +38,7 @@ class AsyncioRedisBackend(Backend):
                 'est_interval': est_interval
             })
 
-        return (f'Hit limiter {key}: {limit} allowed per {interval_ms}ms, ', {
+        return (f'Hit limiter {key}: {limit} allowed per {interval}', {
             'key': key,
             'tat': tat,
             'separation': separation,
