@@ -2,6 +2,7 @@ import functools
 from typing import Optional, Tuple, Callable
 
 from sweelimiter.api.backend import Backend
+from sweelimiter.api.interval import Interval
 
 try:
     from redis import Redis
@@ -11,20 +12,20 @@ except ImportError:
 
 class RedisBackend(Backend):
 
-    async def process(self, key: str, interval_ms: int, limit: int) -> Tuple[Optional[str], dict]:
+    async def process(self, key: str, interval: Interval, limit: int) -> Tuple[Optional[str], dict]:
         redis_key = 'limiter_' + key
         r = self._redis()
 
         seconds, microseconds = r.time()
         time_now = int(seconds * 1000 + microseconds / 1000)
 
-        separation = round(interval_ms / limit)
+        separation = round(interval.to_miliseconds() / limit)
 
         r.setnx(redis_key, 0)
         tat = max(int(r.get(redis_key)), time_now)
 
         wait_left = tat - time_now
-        est_interval = interval_ms - separation
+        est_interval = interval.to_miliseconds() - separation
 
         if wait_left <= est_interval:
             new_tat = max(tat, time_now) + separation
@@ -37,7 +38,7 @@ class RedisBackend(Backend):
                 'est_interval': est_interval
             })
 
-        return (f'Hit limiter {key}: {limit} allowed per {interval_ms}ms, ', {
+        return (f'Hit limiter {key}: {limit} allowed per {interval}, ', {
             'key': key,
             'tat': tat,
             'separation': separation,
